let palette = ["#caf0f8", "#ade8f4", "#90e0ef", "#00b4d8", "#0096c7"];
let backgroundColor = "#0d1321";
let font;

let sound;
let audioText = "(tap to play audio)";

let splatter = [];
let rainfall = [];

function preload() {
  font = loadFont("BagnardSans.otf");
  sound = new Howl({
      src: ['rain.mp3'],
      sprite: {
        rain: [1000, 29000, true]
      }
  });
}

function setup() {
  let cnv = createCanvas(windowWidth, windowHeight, WEBGL);
  cnv.mouseClicked(playNoise);

  angleMode(DEGREES);
  background(backgroundColor);

  // Activate the flowfield we're going to use
  // Can be curved, truncated, zigzag, seabed, or waves
  brush.field("curved");

  // Pre-render the rain and the splatter since it's expensive
  // to do on the fly
  for (let i = 0; i < 5; i++) {
    let smudge = createFramebuffer();
    drawFramebufferSplatter(smudge) ;
    splatter.push(smudge);
    
    let rain = createFramebuffer();
    drawFramebufferRainfall(rain);
    rainfall.push(rain);
  }

  document.getElementById("loading").style.display = "none";
}

function draw() {
  frameRate(10);
  translate(-width / 2, -height / 2);

  tint(255, random(100, 180));
  image(random(splatter), 0, 0, width, height);
  drawText();
  tint(255, 255);
  image(random(rainfall), 0, 0, width, height);
}

function windowResized() {
  resizeCanvas(windowWidth, windowHeight);
  
  for (let i = 0; i < 5; i++) {
    splatter[i].resize(width, height);
    drawFramebufferSplatter(splatter[i]);
    rainfall[i].resize(width, height);
    drawFramebufferRainfall(rainfall[i]);
  }
}

function drawFramebufferSplatter(fb) {
  fb.begin();
  clear();
  translate(-width / 2, -height / 2);
  background(backgroundColor);
  drawSplatter(1);
  fb.end();
}

function drawFramebufferRainfall(fb) {
  fb.begin();
  clear();
  translate(-width / 2, -height / 2);
  drawRainfall(5);
  fb.end();
}

function drawSplatter(limit) {
  // Draw rain splatter on the screen
  for (let i = 0; i < limit; i++) {
    let droplet = {
      paint: random(palette),
      x: random(width),
      y: random(height),
      radius: random(5, 10),
      bleed: random(0.2),
    };

    brush.field("curved");
    brush.fill(droplet.paint, 110);
    brush.set("marker", droplet.paint, 1);
    brush.bleed(droplet.bleed, "out");
    brush.circle(droplet.x, droplet.y, droplet.radius);
  }
}

function drawRainfall(limit) {
  brush.noField();
  brush.set("marker2", random(["#393056", "#5e548e", "#6d597a"]), random(0.1, 0.5));
  for (let i = 0; i < limit; i++) {
    brush.flowLine(random(width), random(height), random(20, 180), 150); 
  }
}

// Function for writing the text in the middle
// of the screen.
function drawText() {
  // Adjust the font size depending on the width.
  let textScale = width > 420 ? 1 : 0.6;
  textFont(font);
  textAlign(CENTER);
  
  fill("#caf0f8");
  textSize(80 * textScale);
  text("Rain", width / 2, height / 3);
  
  fill("#ffb4a2");
  textSize(30 * textScale);

  text(audioText, width / 2, height / 3 + 60 * textScale);
}

function playNoise() {
  if (sound.playing()) {
    sound.pause();
    audioText = "(tap to play audio)";
  } else {
    sound.play('rain');
    audioText = "(tap to pause audio)";
  }
}

